@@ -1,7 +1,11 @@
-#dyn.load("../src/yaml.so")
-#for (f in list.files("../R", full.names = TRUE))
-#  source(f)
-library(yaml)
+if (file.exists("../src/yaml.so")) {
+  dyn.load("../src/yaml.so")
+  for (f in list.files("../R", full.names = TRUE)) {
+    source(f)
+  }
+} else {
+  library(yaml)
+}
 
 assert <- function(bool) {
   if (!bool) stop(bool, " is not TRUE")
@@ -15,7 +19,7 @@ assert_nan <- function(value) {
 assert_lists_equal <- function(expected, actual) {
   if (any(sort(names(expected)) != sort(names(actual)))) stop("Lists are not equal (names differ)")
   if (any(class(expected) != class(actual))) stop("Lists are not equal (classes differ)")
-  
+
   for (n in names(expected)) {
     e <- expected[[n]]
     a <- actual[[n]]
